<h1 align="center">
  <b>cpymadtools</b>
</h1>

<p align="center">
  <!-- General DOI -->
  <a href="https://zenodo.org/badge/latestdoi/564782468">
    <img alt="DOI" src="https://zenodo.org/badge/564782468.svg">
  </a>
</p>

The `cpymadtools` package is a lightweigth pythonic wrapper around `cpymad` for `MAD-X` studies.


Link to [documentation].

## License

Copyright &copy; 2022 Felix Soubelet. [MIT License](LICENSE)

[documentation]: https://fsoubelet.github.io/cpymadtools/
